package main

import (
	"bytes"
	"fmt"
	"git.kuschku.de/justJanne/bahn-api"
	matrixbot "git.kuschku.de/justJanne/stateless-matrix-bot-framework"
	"html/template"
	"net/http"
	"strings"
)

var bahnTpl *template.Template

func initTrainHandler() error {
	var err error
	bahnTpl, err = template.New("bahn").Parse(`{{- /*gotype: bahn.Timetable*/ -}}
<b>{{.Station}}</b> Abfahrten
{{- range .Stops -}}
    {{- if .Departure -}}
        {{- if .Departure.Line -}}
        <li>{{- if .Departure.ChangedTime -}}{{.Departure.ChangedTime}}{{- else if .Departure.PlannedTime -}}{{.Departure.PlannedTime}}{{- end -}}
            · <b>{{ .Departure.Line }}</b></li>
        {{- else if .TripLabel.TripCategory -}}
            {{- if .TripLabel.TripNumber -}}
                <li>{{- if .Departure.ChangedTime -}}{{.Departure.ChangedTime}}{{- else if .Departure.PlannedTime -}}{{.Departure.PlannedTime}}{{- end -}}
                    · <b>{{ .TripLabel.TripCategory }} {{ .TripLabel.TripNumber }}</b></li>
            {{- end -}}
        {{- end -}}
    {{- end -}}
{{- end -}}`)
	return err
}

func handleTrains(bot *matrixbot.MatrixBot, notification matrixbot.Notification) error {
	elements := strings.SplitN(strings.TrimSpace(notification.Content.Body), " ", 3)
	response, err := http.Get(fmt.Sprintf("https://iris.noncd.db.de/iris-tts/timetable/fchg/%s", elements[1]))
	if err != nil {
		return err
	}
	timetable, err := bahn.TimetableFromReader(response.Body)
	if err != nil {
		return err
	}
	buf := new(bytes.Buffer)
	err = bahnTpl.Execute(buf, timetable)
	if err != nil {
		return err
	}
	return matrixbot.SendMessage(*bot.Token, notification.RoomId, matrixbot.MessageContent{
		FormattedBody: buf.String(),
		Format:        "org.matrix.custom.html",
		MsgType:       "m.text",
	})
}
